@@ -1130,10 +1130,10 @@ class VariableClUpdateProfileRepository(ReadonlyVariable):
         try:
             rep_set = self.Get(self.storage)
             branch = self.Get(self.branch)
-            rep = rep_set.get_repository(url, branch)
+            rep = rep_set.get_repository(url, branch=None)
             if rep and self.Get(self.sync_set) == 'on':
                 rep.sync()
-            return rep_set.get_repository(url, branch) or ""
+            return rep_set.get_repository(url, branch=None) or ""
         except GitError:
             return ""
 
